@@ -21,7 +21,8 @@ bind_est_gof <- function(est, gof) {
   bad <- c("part", "term", "model", "group", "statistic")
   bad <- stats::na.omit(match(bad, colnames(est)))
 
-  idx <- sapply(colnames(gof), function(x) { # first matches
+  idx <- sapply(colnames(gof), function(x) {
+    # first matches
     setdiff(grep(x, colnames(est), fixed = TRUE), bad)[1]
   })
   idx <- stats::na.omit(idx)
