@@ -3,24 +3,27 @@
 #' @inheritParams factory_gt
 #' @noRd
 #' @return kableExtra object
-factory_kableExtra <- function(tab,
-                               align = NULL,
-                               hrule = NULL,
-                               hgroup = NULL,
-                               hindent = FALSE,
-                               notes = NULL,
-                               title = NULL,
-                               escape = TRUE,
-                               output_format = "kableExtra",
-                               output_file = NULL,
-                               ...) {
-
+factory_kableExtra <- function(
+  tab,
+  align = NULL,
+  hrule = NULL,
+  hgroup = NULL,
+  hindent = FALSE,
+  notes = NULL,
+  title = NULL,
+  escape = TRUE,
+  output_format = "kableExtra",
+  output_file = NULL,
+  ...
+) {
   insight::check_if_installed("kableExtra")
 
   span_list <- get_span_kableExtra(tab)
 
   # escape
-  if (isTRUE(escape) && isTRUE(output_format %in% c("latex", "html", "typst"))) {
+  if (
+    isTRUE(escape) && isTRUE(output_format %in% c("latex", "html", "typst"))
+  ) {
     # escape ourselves rather than use the kableExtra escaping
     escape <- FALSE
 
@@ -29,7 +32,8 @@ factory_kableExtra <- function(tab,
       output_format = output_format,
       span_list = span_list,
       title = title,
-      notes = notes)
+      notes = notes
+    )
     tab <- tmp$tab
     title <- tmp$title
     notes <- tmp$notes
@@ -50,18 +54,36 @@ factory_kableExtra <- function(tab,
   row.names(tab) <- NULL
 
   # kbl arguments
-  valid <- c("x", "align", "caption", "format", "booktabs", "linesep",
-             "format.args", "escape", "table.attr", "longtable", "valign",
-             "position", "centering", "vline", "toprule", "bottomrule",
-             "midrule", "caption.short", "table.envir", "col.names")
+  valid <- c(
+    "x",
+    "align",
+    "caption",
+    "format",
+    "booktabs",
+    "linesep",
+    "format.args",
+    "escape",
+    "table.attr",
+    "longtable",
+    "valign",
+    "position",
+    "centering",
+    "vline",
+    "toprule",
+    "bottomrule",
+    "midrule",
+    "caption.short",
+    "table.envir",
+    "col.names"
+  )
 
   arguments <- c(
     list(...),
-    "caption"   = title,
-    "format"    = kable_format,
-    "booktabs"  = TRUE,
+    "caption" = title,
+    "format" = kable_format,
+    "booktabs" = TRUE,
     "escape" = escape,
-    "linesep"   = "",
+    "linesep" = "",
     "row.names" = NULL
   )
 
@@ -73,29 +95,45 @@ factory_kableExtra <- function(tab,
     ]}
   "
 
-  if (output_format %in% c("latex", "latex_tabular") &&
-      settings_equal("format_numeric_latex", "siunitx")) {
+  if (
+    output_format %in%
+      c("latex", "latex_tabular") &&
+      settings_equal("format_numeric_latex", "siunitx")
+  ) {
     invisible(knitr::knit_meta_add(list(
-      rmarkdown::latex_dependency("booktabs"))))
+      rmarkdown::latex_dependency("booktabs")
+    )))
     invisible(knitr::knit_meta_add(list(
-      rmarkdown::latex_dependency("siunitx", extra_lines = extra_siunitx))))
+      rmarkdown::latex_dependency("siunitx", extra_lines = extra_siunitx)
+    )))
   }
 
   ## align
   if (!is.null(align)) {
     for (i in seq_along(align)) {
       if (align[i] == "d") {
-        if (output_format %in%  c("latex", "latex_tabular")) {
+        if (output_format %in% c("latex", "latex_tabular")) {
           ## protect strings from siunitx
-          tab[[i]] <- ifelse(!grepl("[0-9]", tab[[i]]), sprintf("{%s}", tab[[i]]), tab[[i]]) 
+          tab[[i]] <- ifelse(
+            !grepl("[0-9]", tab[[i]]),
+            sprintf("{%s}", tab[[i]]),
+            tab[[i]]
+          )
         } else {
-          tab[[i]] <- ifelse(grepl("[0-9]", tab[[i]]), sprintf("$%s$", tab[[i]]), tab[[i]])
+          tab[[i]] <- ifelse(
+            grepl("[0-9]", tab[[i]]),
+            sprintf("$%s$", tab[[i]]),
+            tab[[i]]
+          )
         }
       }
     }
     if (any(grepl("d", align))) {
       ## protect column labels
-      colnames(tab)[align == "d"] <- sprintf("{%s}", colnames(tab)[align == "d"])
+      colnames(tab)[align == "d"] <- sprintf(
+        "{%s}",
+        colnames(tab)[align == "d"]
+      )
     }
     arguments[["align"]] <- align
   }
@@ -113,10 +151,14 @@ factory_kableExtra <- function(tab,
   # kableExtra sometimes converts (1), (2) to list items, which breaks formatting
   # insert think white non-breaking space
   if (output_format %in% c("html", "kableExtra")) {
-      regex <- paste0(paste(1:12, collapse = "|"), "|", paste(utils::as.roman(1:12), collapse = "|"))
-      regex <- paste0("^\\(", regex, "\\)$")
-      idx <- grepl(regex, colnames(tab))
-      colnames(tab)[idx] <- paste0("&nbsp;", colnames(tab)[idx])
+    regex <- paste0(
+      paste(1:12, collapse = "|"),
+      "|",
+      paste(utils::as.roman(1:12), collapse = "|")
+    )
+    regex <- paste0("^\\(", regex, "\\)$")
+    idx <- grepl(regex, colnames(tab))
+    colnames(tab)[idx] <- paste0("&nbsp;", colnames(tab)[idx])
   }
 
   # issue #761: only matters for shape
@@ -128,18 +170,27 @@ factory_kableExtra <- function(tab,
   out <- do.call(kableExtra::kbl, arguments)
 
   ## footnote arguments
-  valid <- c("footnote_as_chunk", "escape", "threeparttable", "fixed_small_size", "symbol_manual", "title_format")
+  valid <- c(
+    "footnote_as_chunk",
+    "escape",
+    "threeparttable",
+    "fixed_small_size",
+    "symbol_manual",
+    "title_format"
+  )
   arguments <- list(...)
   arguments <- arguments[base::intersect(names(arguments), valid)]
 
   ## kableExtra::footnote bug when adding multiple notes with threeparttable in LaTeX
   ## combine notes
-  if (identical(output_format, "latex") &&
+  if (
+    identical(output_format, "latex") &&
       !is.null(notes) &&
       length(notes) > 1 &&
       "threeparttable" %in% names(arguments) &&
-      isTRUE(arguments[["threeparttable"]])) {
-      notes <- paste(notes, collapse = " ")
+      isTRUE(arguments[["threeparttable"]])
+  ) {
+    notes <- paste(notes, collapse = " ")
   }
 
   ## user-supplied notes at the bottom of table
@@ -147,7 +198,11 @@ factory_kableExtra <- function(tab,
     ## kableExtra::footnote does not support markdown
     ## kableExtra::add_footnote does not support longtable
     if (output_format %in% c("kableExtra", "html", "latex")) {
-      if (isTRUE(kable_format == "latex") && any(grepl(" < ", notes)) && !isTRUE(escape)) {
+      if (
+        isTRUE(kable_format == "latex") &&
+          any(grepl(" < ", notes)) &&
+          !isTRUE(escape)
+      ) {
         notes <- gsub(" < ", " $<$ ", notes)
         arguments[["escape"]] <- FALSE
       }
@@ -157,7 +212,7 @@ factory_kableExtra <- function(tab,
       arguments[["general_title"]] <- ""
       arguments[["kable_input"]] <- out
 
-      # Issue #855: When output="kableExtra", we do not know the ultimate output format, 
+      # Issue #855: When output="kableExtra", we do not know the ultimate output format,
       # so we must rely on kableExtra's escaping for notes.
       if (identical(output_format, "kableExtra")) {
         arguments[["escape"]] <- escape
@@ -168,24 +223,34 @@ factory_kableExtra <- function(tab,
       }
     } else if (identical(output_format, "markdown")) {
       for (n in notes) {
-        out <- kableExtra::add_footnote(out, label = n, notation = "none", escape = FALSE)
+        out <- kableExtra::add_footnote(
+          out,
+          label = n,
+          notation = "none",
+          escape = FALSE
+        )
       }
     }
   }
 
   # theme
-  theme_ms <- getOption("modelsummary_theme_kableExtra",
-                        default = theme_ms_kableExtra)
+  theme_ms <- getOption(
+    "modelsummary_theme_kableExtra",
+    default = theme_ms_kableExtra
+  )
   out <- theme_ms(
     out,
     output_format = output_format,
     hrule = hrule,
     hgroup = hgroup,
     hindent = hindent,
-    ...)
+    ...
+  )
 
   # span: apply (not supported in markdown)
-  if (!is.null(span_list) && output_format %in% c("kableExtra", "latex", "html")) {
+  if (
+    !is.null(span_list) && output_format %in% c("kableExtra", "latex", "html")
+  ) {
     for (i in 1:length(span_list)) {
       sp <- span_list[[i]]
       names(span_list[[i]]) <- gsub("&nbsp;", " ", names(span_list[[i]]))
